@@ -219,7 +219,11 @@ class SamFileType(enum.Enum):
 
 
 def _pysam_open(
-    path: SamPath, open_for_reading: bool, file_type: Optional[SamFileType] = None, **kwargs: Any
+    path: SamPath,
+    open_for_reading: bool,
+    file_type: Optional[SamFileType] = None,
+    unmapped: bool = False,
+    **kwargs: Any,
 ) -> SamFile:
     """Opens a SAM/BAM/CRAM for reading or writing.
 
@@ -228,6 +232,7 @@ def _pysam_open(
         open_for_reading: True to open for reading, false otherwise.
         file_type: the file type to assume when opening the file.  If None, then the file type
             will be auto-detected for reading and must be a path-like object for writing.
+        unmapped: True if the file is unmapped and has no sequence dictionary, False otherwise.
         kwargs: any keyword arguments to be passed to
         :class:`~pysam.AlignmentFile`; may not include "mode".
     """
@@ -251,19 +256,25 @@ def _pysam_open(
     else:
         assert open_for_reading, "Bug: file_type was None but open_for_reading was False"
 
+    if unmapped and open_for_reading:
+        kwargs["check_sq"] = False
+
     # Open it!
     return pysam.AlignmentFile(path, **kwargs)
 
 
-def reader(path: SamPath, file_type: Optional[SamFileType] = None) -> SamFile:
+def reader(
+    path: SamPath, file_type: Optional[SamFileType] = None, unmapped: bool = False
+) -> SamFile:
     """Opens a SAM/BAM/CRAM for reading.
 
     Args:
         path: a file handle or path to the SAM/BAM/CRAM to read or write.
         file_type: the file type to assume when opening the file.  If None, then the file
             type will be auto-detected.
+        unmapped: True if the file is unmapped and has no sequence dictionary, False otherwise.
     """
-    return _pysam_open(path=path, open_for_reading=True, file_type=file_type)
+    return _pysam_open(path=path, open_for_reading=True, file_type=file_type, unmapped=unmapped)
 
 
 def writer(
@@ -287,7 +298,9 @@ def writer(
     key = "text" if isinstance(header, str) else "header"
     kwargs = {key: header}
 
-    return _pysam_open(path=path, open_for_reading=False, file_type=file_type, **kwargs)
+    return _pysam_open(
+        path=path, open_for_reading=False, file_type=file_type, unmapped=False, **kwargs
+    )
 
 
 class _CigarOpUtil:
